@@ -1,33 +1,89 @@
+( cd opt/kde/share/doc/HTML/nl/ark ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ark ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kdf ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kig ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kig ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/juk ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/amor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/karm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/karm ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kate ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kdat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kdat ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kget ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmag ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmag ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmix ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmix ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kodo ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kpat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kpat ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kpdf ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/korn ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kxkb ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kalzium ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/katomic ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/katomic ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ksysguard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ksysguard ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kbounce ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kbounce ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kbattleship ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kbattleship ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kaboodle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kaboodle ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khangman ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khangman ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kfloppy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kfloppy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kpercentage ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kandy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kandy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcalc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcalc ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kdesu ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcron ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kfind ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kiten ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kiten ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kjots ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kjots ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmail ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmoon ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/knode ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/knode ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ksame ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ksame ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ktnef ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ksysv ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ksysv ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kuser ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcoloredit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/klipper ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/klipper ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmousetool ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmousetool ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kompare ; rm -rf common )
@@ -38,20 +94,38 @@
 ( cd opt/kde/share/doc/HTML/nl/konsole ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/konsolekalendar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kpackage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kpackage ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/khelpcenter/faq ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/khelpcenter/glossary ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konquest ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konquest ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kturtle ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kverbos ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kwallet ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kweather ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmenuedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kioslave ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kbackgammon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf fdl-license )
@@ -146,8 +220,6 @@
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/nl/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/nl/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/nl/kcmktalkd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/smb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/spellchecking ; rm -rf common )
@@ -180,6 +252,8 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/lanbrowser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmaccess ; rm -rf common )
@@ -196,6 +270,8 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlaunch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmcss ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/laptop ; rm -rf common )
@@ -220,6 +296,40 @@
 ( cd opt/kde/share/doc/HTML/nl/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/crashes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/babel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/kuick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/webarchiver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/domtreeviewer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/smbmounter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/imgallery ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/khtmlsettings ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/validators ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/uachanger ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/mediaplayer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/dirfilter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kamera ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kamera ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kdeprint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kdeprint ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kasteroids ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kasteroids ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kbruch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kbruch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/keduca ; rm -rf common )
@@ -228,6 +338,12 @@
 ( cd opt/kde/share/doc/HTML/nl/kgamma ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/klatin ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/klines ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/klines ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kmines ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kmines ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmouth ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kmouth ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kmplot ; rm -rf common )
@@ -236,20 +352,40 @@
 ( cd opt/kde/share/doc/HTML/nl/knotes ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kpager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kopete ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kpilot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kpilot ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ksnake ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ksnake ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kspell ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kstars ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kstars ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/ktouch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/ktouch ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/noatun ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/noatun ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/ksplashml ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kblackbox ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kblackbox ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kcharselect ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kcharselect ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kuickshow ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kuickshow ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/klettres ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
-( cd opt/kde/share/doc/HTML/nl/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/nl/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kfouleggs ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kjumpingcube ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kenolaba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kenolaba ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kworldclock ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kteatime ; rm -rf common )
@@ -286,6 +422,8 @@
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/kinfocenter/ioports ; rm -rf common )
@@ -296,5 +434,9 @@
 ( cd opt/kde/share/doc/HTML/nl/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/konqueror ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
 ( cd opt/kde/share/doc/HTML/nl/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/nl/korganizer ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
+( cd opt/kde/share/doc/HTML/nl/atlantik ; rm -rf common )
+( cd opt/kde/share/doc/HTML/nl/atlantik ; ln -sf /opt/kde/share/doc/HTML/nl/common common )
